zfit has been developed with support from the University of Zürich and the Swiss National Science Foundation (SNSF) under contracts 168169, 174182 and 182622.

The idea of zfit is inspired by the `TensorFlowAnalysis <https://gitlab.cern.ch/poluekt/TensorFlowAnalysis>`_ framework developed by Anton Poluektov using the TensorFlow open source library.
